@@ -85,7 +85,7 @@ public:
  */
 class FileList : public TDEListView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
