@@ -26,7 +26,7 @@ class TQLabel;
  */
 class OptionsEditor : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     enum Page {
